LogStore

Struct LogStore 

pub struct LogStore<T>
where T: RaftTypeConfig,
{ pub writer: Sender<Action>, pub reader: Sender<Action>, /* private fields */ }
T::NodeId MUST be a u64 for the LogStore to work correctly.

Fields

writer: Sender<Action>reader: Sender<Action>

Implementations

Source

impl<T> LogStore<T>
where T: RaftTypeConfig,

pub async fn start( base_path: String, sync: LogSync, wal_size: u32, ) -> Result<Self, Error>

Start the LogStore

pub async fn start_writer_migration( base_path: String, wal_size: u32, ) -> Result<Sender<Action>, Error>

Gives you a raw handle to the writer channel to perform manual migrations. Does not start a log store and does not do anything on its own.

pub fn shutdown_handle(&self) -> ShutdownHandle

pub async fn stop(self) -> Result<(), Error>